==> ejc-assistrmat-impl-3.0.0-20220322.020504-1-sources.jar: com/ejianc/business/assist/ownrmat/bean/OwnDetailEntity.java <==
package com.ejianc.business.assist.ownrmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 自有材料摊销-清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proownrmat_own_detail")
public class OwnDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="own_id")
    private Long ownId; // 自有周转材摊销主键
    @TableField(value="material_type_id")
    private Long materialTypeId; // 材料分类id
    @TableField(value="material_type_code")
    private String materialTypeCode; // 材料分类编码
    @TableField(value="material_type_name")
    private String materialTypeName; // 材料分类名称
    @TableField(value="material_id")
    private Long materialId; // 材料id
    @TableField(value="material_code")
    private String materialCode; // 材料编码
    @TableField(value="source_code")
    private String sourceCode; // 材料批次
    @TableField(value="material_name")
    private String materialName; // 材料名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_id")
    private Long unitId; // 计量单位id
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="original_value")
    private BigDecimal originalValue; // 原值(无税)
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="original_value_tax")
    private BigDecimal originalValueTax; // 原值(含税)
    @TableField(value="net_worth")
    private BigDecimal netWorth; // 净值(无税)
    @TableField(value="original_value_price_tax")
    private BigDecimal originalValuePriceTax; // 原值单价(含税)
    @TableField(value="original_value_price")
    private BigDecimal originalValuePrice; // 原值单价(无税)
    @TableField(value="net_worth_tax")
    private BigDecimal netWorthTax; // 净值(含税)
    @TableField(value="residual_value_tax")
    private BigDecimal residualValueTax; // 残值(含税)
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="residual_value")
    private BigDecimal residualValue; // 残值(无税)
    @TableField(value="last_amortization_cycle")
    private String lastAmortizationCycle; // 上次摊销周期
    @TableField(value="amortization_rate")
    private BigDecimal amortizationRate; // 本次摊销比例
    @TableField(value="amortization_mny_tax")
    private BigDecimal amortizationMnyTax; // 本次摊销金额(含税)
    @TableField(value="amortization_mny")
    private BigDecimal amortizationMny; // 本次摊销金额(无税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 材料来源出业务Id
    @TableField(value="amortization_num")
    private Integer amortizationNum; // 摊销周期数
    @TableField(value="used_amortization_num")
    private Integer usedAmortizationNum; // 已生效摊销周期数
    @TableField(value="use_period")
    private Integer usePeriod; // 使用年限（月）
    @TableField(value="residual_value_rate")
    private BigDecimal residualValueRate; // 残值率
    @TableField(value="flow_source_id")
    private Long flowSourceId;// 流水来源单据id
    @TableField(value="flow_source_detail_id")
    private Long flowSourceDetailId;// 流水来源单据明细id

    public Long getFlowSourceId() {
        return flowSourceId;
    }

    public void setFlowSourceId(Long flowSourceId) {
        this.flowSourceId = flowSourceId;
    }

    public Long getFlowSourceDetailId() {
        return flowSourceDetailId;
    }

    public void setFlowSourceDetailId(Long flowSourceDetailId) {
        this.flowSourceDetailId = flowSourceDetailId;
    }

    public Integer getUsePeriod() {
        return usePeriod;
    }

    public void setUsePeriod(Integer usePeriod) {
        this.usePeriod = usePeriod;
    }

    public BigDecimal getResidualValueRate() {
        return residualValueRate;
    }

    public void setResidualValueRate(BigDecimal residualValueRate) {
        this.residualValueRate = residualValueRate;
    }

    public Integer getUsedAmortizationNum() {
        return usedAmortizationNum;
    }

    public void setUsedAmortizationNum(Integer usedAmortizationNum) {
        this.usedAmortizationNum = usedAmortizationNum;
    }

    public Integer getAmortizationNum() {
        return amortizationNum;
    }

    public void setAmortizationNum(Integer amortizationNum) {
        this.amortizationNum = amortizationNum;
    }

    public String getSourceCode() {
        return sourceCode;
    }

    public void setSourceCode(String sourceCode) {
        this.sourceCode = sourceCode;
    }

    public Long getOwnId() {
        return ownId;
    }

    public void setOwnId(Long ownId) {
        this.ownId = ownId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getOriginalValue() {
        return originalValue;
    }

    public void setOriginalValue(BigDecimal originalValue) {
        this.originalValue = originalValue;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getOriginalValueTax() {
        return originalValueTax;
    }

    public void setOriginalValueTax(BigDecimal originalValueTax) {
        this.originalValueTax = originalValueTax;
    }
    public BigDecimal getNetWorth() {
        return netWorth;
    }

    public void setNetWorth(BigDecimal netWorth) {
        this.netWorth = netWorth;
    }
    public BigDecimal getOriginalValuePriceTax() {
        return originalValuePriceTax;
    }

    public void setOriginalValuePriceTax(BigDecimal originalValuePriceTax) {
        this.originalValuePriceTax = originalValuePriceTax;
    }
    public BigDecimal getOriginalValuePrice() {
        return originalValuePrice;
    }

    public void setOriginalValuePrice(BigDecimal originalValuePrice) {
        this.originalValuePrice = originalValuePrice;
    }
    public BigDecimal getNetWorthTax() {
        return netWorthTax;
    }

    public void setNetWorthTax(BigDecimal netWorthTax) {
        this.netWorthTax = netWorthTax;
    }
    public BigDecimal getResidualValueTax() {
        return residualValueTax;
    }

    public void setResidualValueTax(BigDecimal residualValueTax) {
        this.residualValueTax = residualValueTax;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getResidualValue() {
        return residualValue;
    }

    public void setResidualValue(BigDecimal residualValue) {
        this.residualValue = residualValue;
    }
    public String getLastAmortizationCycle() {
        return lastAmortizationCycle;
    }

    public void setLastAmortizationCycle(String lastAmortizationCycle) {
        this.lastAmortizationCycle = lastAmortizationCycle;
    }
    public BigDecimal getAmortizationRate() {
        return amortizationRate;
    }

    public void setAmortizationRate(BigDecimal amortizationRate) {
        this.amortizationRate = amortizationRate;
    }
    public BigDecimal getAmortizationMnyTax() {
        return amortizationMnyTax;
    }

    public void setAmortizationMnyTax(BigDecimal amortizationMnyTax) {
        this.amortizationMnyTax = amortizationMnyTax;
    }
    public BigDecimal getAmortizationMny() {
        return amortizationMny;
    }

    public void setAmortizationMny(BigDecimal amortizationMny) {
        this.amortizationMny = amortizationMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}

==> ejc-assistrmat-impl-3.0.0-20220406.073517-49-sources.jar: com/ejianc/business/assist/ownrmat/bean/OwnDetailEntity.java <==
package com.ejianc.business.assist.ownrmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 自有材料摊销-清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistownrmat_own_detail")
public class OwnDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="own_id")
    private Long ownId; // 自有周转材摊销主键
    @TableField(value="material_type_id")
    private Long materialTypeId; // 材料分类id
    @TableField(value="material_type_code")
    private String materialTypeCode; // 材料分类编码
    @TableField(value="material_type_name")
    private String materialTypeName; // 材料分类名称
    @TableField(value="material_id")
    private Long materialId; // 材料id
    @TableField(value="material_code")
    private String materialCode; // 材料编码
    @TableField(value="source_code")
    private String sourceCode; // 材料批次
    @TableField(value="material_name")
    private String materialName; // 材料名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_id")
    private Long unitId; // 计量单位id
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="original_value")
    private BigDecimal originalValue; // 原值(无税)
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="original_value_tax")
    private BigDecimal originalValueTax; // 原值(含税)
    @TableField(value="net_worth")
    private BigDecimal netWorth; // 净值(无税)
    @TableField(value="original_value_price_tax")
    private BigDecimal originalValuePriceTax; // 原值单价(含税)
    @TableField(value="original_value_price")
    private BigDecimal originalValuePrice; // 原值单价(无税)
    @TableField(value="net_worth_tax")
    private BigDecimal netWorthTax; // 净值(含税)
    @TableField(value="residual_value_tax")
    private BigDecimal residualValueTax; // 残值(含税)
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="residual_value")
    private BigDecimal residualValue; // 残值(无税)
    @TableField(value="last_amortization_cycle")
    private String lastAmortizationCycle; // 上次摊销周期
    @TableField(value="amortization_rate")
    private BigDecimal amortizationRate; // 本次摊销比例
    @TableField(value="amortization_mny_tax")
    private BigDecimal amortizationMnyTax; // 本次摊销金额(含税)
    @TableField(value="amortization_mny")
    private BigDecimal amortizationMny; // 本次摊销金额(无税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 材料来源出业务Id
    @TableField(value="amortization_num")
    private Integer amortizationNum; // 摊销周期数
    @TableField(value="used_amortization_num")
    private Integer usedAmortizationNum; // 已生效摊销周期数
    @TableField(value="use_period")
    private Integer usePeriod; // 使用年限（月）
    @TableField(value="residual_value_rate")
    private BigDecimal residualValueRate; // 残值率
    @TableField(value="flow_source_id")
    private Long flowSourceId;// 流水来源单据id
    @TableField(value="flow_source_detail_id")
    private Long flowSourceDetailId;// 流水来源单据明细id

    public Long getFlowSourceId() {
        return flowSourceId;
    }

    public void setFlowSourceId(Long flowSourceId) {
        this.flowSourceId = flowSourceId;
    }

    public Long getFlowSourceDetailId() {
        return flowSourceDetailId;
    }

    public void setFlowSourceDetailId(Long flowSourceDetailId) {
        this.flowSourceDetailId = flowSourceDetailId;
    }

    public Integer getUsePeriod() {
        return usePeriod;
    }

    public void setUsePeriod(Integer usePeriod) {
        this.usePeriod = usePeriod;
    }

    public BigDecimal getResidualValueRate() {
        return residualValueRate;
    }

    public void setResidualValueRate(BigDecimal residualValueRate) {
        this.residualValueRate = residualValueRate;
    }

    public Integer getUsedAmortizationNum() {
        return usedAmortizationNum;
    }

    public void setUsedAmortizationNum(Integer usedAmortizationNum) {
        this.usedAmortizationNum = usedAmortizationNum;
    }

    public Integer getAmortizationNum() {
        return amortizationNum;
    }

    public void setAmortizationNum(Integer amortizationNum) {
        this.amortizationNum = amortizationNum;
    }

    public String getSourceCode() {
        return sourceCode;
    }

    public void setSourceCode(String sourceCode) {
        this.sourceCode = sourceCode;
    }

    public Long getOwnId() {
        return ownId;
    }

    public void setOwnId(Long ownId) {
        this.ownId = ownId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getOriginalValue() {
        return originalValue;
    }

    public void setOriginalValue(BigDecimal originalValue) {
        this.originalValue = originalValue;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getOriginalValueTax() {
        return originalValueTax;
    }

    public void setOriginalValueTax(BigDecimal originalValueTax) {
        this.originalValueTax = originalValueTax;
    }
    public BigDecimal getNetWorth() {
        return netWorth;
    }

    public void setNetWorth(BigDecimal netWorth) {
        this.netWorth = netWorth;
    }
    public BigDecimal getOriginalValuePriceTax() {
        return originalValuePriceTax;
    }

    public void setOriginalValuePriceTax(BigDecimal originalValuePriceTax) {
        this.originalValuePriceTax = originalValuePriceTax;
    }
    public BigDecimal getOriginalValuePrice() {
        return originalValuePrice;
    }

    public void setOriginalValuePrice(BigDecimal originalValuePrice) {
        this.originalValuePrice = originalValuePrice;
    }
    public BigDecimal getNetWorthTax() {
        return netWorthTax;
    }

    public void setNetWorthTax(BigDecimal netWorthTax) {
        this.netWorthTax = netWorthTax;
    }
    public BigDecimal getResidualValueTax() {
        return residualValueTax;
    }

    public void setResidualValueTax(BigDecimal residualValueTax) {
        this.residualValueTax = residualValueTax;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getResidualValue() {
        return residualValue;
    }

    public void setResidualValue(BigDecimal residualValue) {
        this.residualValue = residualValue;
    }
    public String getLastAmortizationCycle() {
        return lastAmortizationCycle;
    }

    public void setLastAmortizationCycle(String lastAmortizationCycle) {
        this.lastAmortizationCycle = lastAmortizationCycle;
    }
    public BigDecimal getAmortizationRate() {
        return amortizationRate;
    }

    public void setAmortizationRate(BigDecimal amortizationRate) {
        this.amortizationRate = amortizationRate;
    }
    public BigDecimal getAmortizationMnyTax() {
        return amortizationMnyTax;
    }

    public void setAmortizationMnyTax(BigDecimal amortizationMnyTax) {
        this.amortizationMnyTax = amortizationMnyTax;
    }
    public BigDecimal getAmortizationMny() {
        return amortizationMny;
    }

    public void setAmortizationMny(BigDecimal amortizationMny) {
        this.amortizationMny = amortizationMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}
